@@ -31,6 +31,14 @@
 #include "mfx_enc_common.h"
 #include "assert.h"
 
+static inline bool operator==(mfxVP9SegmentParam const& l, mfxVP9SegmentParam const& r)
+{
+    return MFX_EQ_FIELD(FeatureEnabled)
+        && MFX_EQ_FIELD(QIndexDelta)
+        && MFX_EQ_FIELD(LoopFilterLevelDelta)
+        && MFX_EQ_FIELD(ReferenceFrame);
+}
+
 namespace MfxHwVP9Encode
 {
 
@@ -265,16 +273,6 @@ enum // identifies memory type at encoder input w/o any details
     inline mfxU32 CeilLog2(mfxU32 x) { mfxU32 l = 0; while (x > (1U << l)) l++; return l; }
     inline mfxU32 FloorLog2(mfxU32 x) { mfxU32 l = 0; while (x >= (1U << (l + 1))) l++; return l; }
 
-    inline bool IsOn(mfxU16 opt)
-    {
-        return opt == MFX_CODINGOPTION_ON;
-    }
-
-    inline bool IsOff(mfxU16 opt)
-    {
-        return opt == MFX_CODINGOPTION_OFF;
-    }
-
     template<class T> struct ExtBufTypeToId {};
 
 #define BIND_EXTBUF_TYPE_TO_ID(TYPE, ID) template<> struct ExtBufTypeToId<TYPE> { enum { id = ID }; }
@@ -442,7 +440,8 @@ template <typename T> mfxStatus RemoveExtBuffer(T & par, mfxU32 id)
 
         mfxStatus Alloc(
             VideoCORE* pCore,
-            mfxFrameAllocRequest & req);
+            mfxFrameAllocRequest & req,
+            bool isCopyRequired);
 
         mfxStatus Release();
 
@@ -523,10 +522,12 @@ constexpr auto NUM_OF_SUPPORTED_EXT_BUFFERS = 7; // mfxExtVP9Param, mfxExtOpaque
         VP9MfxVideoParam();
         VP9MfxVideoParam(VP9MfxVideoParam const &);
         VP9MfxVideoParam(mfxVideoParam const &);
+        VP9MfxVideoParam(mfxVideoParam const & par, eMFXHWType const & platform);
 
         VP9MfxVideoParam & operator = (VP9MfxVideoParam const &);
         VP9MfxVideoParam & operator = (mfxVideoParam const &);
 
+        eMFXHWType m_platform;
         mfxU16 m_inMemType;
         mfxU32 m_targetKbps;
         mfxU32 m_maxKbps;
@@ -600,7 +601,7 @@ constexpr auto NUM_OF_SUPPORTED_EXT_BUFFERS = 7; // mfxExtVP9Param, mfxExtOpaque
         std::vector<mfxFrameSurface1>   m_surfaces;
     public:
         InternalFrames() {}
-        mfxStatus Init(VideoCORE *pCore, mfxFrameAllocRequest *pAllocReq);
+        mfxStatus Init(VideoCORE *pCore, mfxFrameAllocRequest *pAllocReq, bool isCopyRequired);
         sFrameEx * GetFreeFrame();
         mfxStatus  GetFrame(mfxU32 numFrame, sFrameEx * &Frame);
         mfxStatus Release();
@@ -906,29 +907,12 @@ inline bool CompareSegmentMaps(mfxExtVP9Segmentation const & first, mfxExtVP9Seg
 
 inline bool CompareSegmentParams(mfxExtVP9Segmentation const & first, mfxExtVP9Segmentation const & second)
 {
-    bool equal = false;
+    if (first.NumSegments != second.NumSegments)
+        return false;
 
-    if (first.NumSegments == second.NumSegments)
-    {
-        mfxU8 equalParams = 0;
-        for (mfxU8 i = 0; i < first.NumSegments; i++)
-        {
-            if (0 == memcmp(&first.Segment[i], &second.Segment[i], sizeof(mfxVP9SegmentParam)))
-            {
-                equalParams++;
-            }
-        }
-
-        if (equalParams == first.NumSegments)
-        {
-            equal = true;
-        }
-    }
-
-    return equal;
+    return std::equal(first.Segment, first.Segment + first.NumSegments, second.Segment);
 }
 
-
 inline void CopySegmentationBuffer(mfxExtVP9Segmentation & dst, mfxExtVP9Segmentation const & src)
 {
     mfxU8* tmp = dst.SegmentId;
