@@ -399,12 +399,12 @@ mfxStatus VideoVPPBase::QueryIOSurf(VideoCORE* core, mfxVideoParam *par, mfxFram
         if( !bSWLib )
         {
             // suggested
-            request[VPP_IN].NumFrameSuggested = MFX_MAX(request[VPP_IN].NumFrameSuggested, hwRequest[VPP_IN].NumFrameSuggested);
-            request[VPP_OUT].NumFrameSuggested = MFX_MAX(request[VPP_OUT].NumFrameSuggested, hwRequest[VPP_OUT].NumFrameSuggested);
+            request[VPP_IN].NumFrameSuggested  = std::max(request[VPP_IN].NumFrameSuggested,  hwRequest[VPP_IN].NumFrameSuggested);
+            request[VPP_OUT].NumFrameSuggested = std::max(request[VPP_OUT].NumFrameSuggested, hwRequest[VPP_OUT].NumFrameSuggested);
 
             // min
-            request[VPP_IN].NumFrameMin  = MFX_MAX(request[VPP_IN].NumFrameMin, hwRequest[VPP_IN].NumFrameMin);
-            request[VPP_OUT].NumFrameMin = MFX_MAX(request[VPP_OUT].NumFrameMin, hwRequest[VPP_OUT].NumFrameMin);
+            request[VPP_IN].NumFrameMin  = std::max(request[VPP_IN].NumFrameMin,  hwRequest[VPP_IN].NumFrameMin);
+            request[VPP_OUT].NumFrameMin = std::max(request[VPP_OUT].NumFrameMin, hwRequest[VPP_OUT].NumFrameMin);
         }
 
         mfxU16 vppAsyncDepth = (0 == par->AsyncDepth) ? MFX_AUTO_ASYNC_DEPTH_VALUE : par->AsyncDepth;
@@ -873,7 +873,7 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
 
                                 if(MFX_EXTBUFF_VPP_COMPOSITE == extDoUseIn->AlgList[algIdx])
                                 {
-                                    mfxSts = MFX_ERR_INVALID_VIDEO_PARAM;
+                                    mfxSts = MFX_ERR_UNSUPPORTED;
                                     continue; // stop working with ExtParam[i]
                                 }
 
@@ -962,6 +962,11 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
 #if (MFX_VERSION >= 1027)
             out->vpp.In.FourCC != MFX_FOURCC_Y210 &&
             out->vpp.In.FourCC != MFX_FOURCC_Y410 &&
+#endif
+#if (MFX_VERSION >= 1031)
+            out->vpp.In.FourCC != MFX_FOURCC_P016 &&
+            out->vpp.In.FourCC != MFX_FOURCC_Y216 &&
+            out->vpp.In.FourCC != MFX_FOURCC_Y416 &&
 #endif
             out->vpp.In.FourCC != MFX_FOURCC_AYUV)
         {
@@ -1029,6 +1034,11 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
 #if (MFX_VERSION >= 1027)
             out->vpp.Out.FourCC != MFX_FOURCC_Y210 &&
             out->vpp.Out.FourCC != MFX_FOURCC_Y410 &&
+#endif
+#if (MFX_VERSION >= 1031)
+            out->vpp.Out.FourCC != MFX_FOURCC_P016 &&
+            out->vpp.Out.FourCC != MFX_FOURCC_Y216 &&
+            out->vpp.Out.FourCC != MFX_FOURCC_Y416 &&
 #endif
             out->vpp.Out.FourCC != MFX_FOURCC_AYUV &&
             out->vpp.Out.FourCC != MFX_FOURCC_A2RGB10 )
@@ -1112,7 +1122,9 @@ mfxStatus VideoVPPBase::Query(VideoCORE * core, mfxVideoParam *in, mfxVideoParam
             }
             else
             {
-                hwQuerySts = MFX_WRN_PARTIAL_ACCELERATION;
+                // doesn't support sw fallback now so return MFX_ERR_UNSUPPORTED
+                // will return MFX_WRN_PARTIAL_ACCELERATION after enabling sw fallback
+                hwQuerySts = MFX_ERR_UNSUPPORTED;
             }
         }
         else
@@ -1314,6 +1326,10 @@ mfxStatus VideoVPP_HW::InternalInit(mfxVideoParam *par)
         bIsFilterSkipped = true;
         sts = MFX_ERR_NONE;
     }
+    if (MFX_WRN_PARTIAL_ACCELERATION == sts) // doesn't support sw fallback
+    {
+        sts = MFX_ERR_INVALID_VIDEO_PARAM;
+    }
     if (MFX_ERR_NONE != sts)
     {
         m_pHWVPP.reset(0);
