@@ -20,6 +20,11 @@ or https://software.intel.com/en-us/media-client-solutions-support.
 #ifndef __SAMPLE_MULTI_TRANSCODE_H__
 #define __SAMPLE_MULTI_TRANSCODE_H__
 
+#include "mfxdefs.h"
+#if (defined(_WIN32) || defined(_WIN64)) && (MFX_VERSION >= 1031)
+#include "mfxadapter.h"
+#endif
+
 #include "transcode_utils.h"
 #include "pipeline_transcode.h"
 #include "sample_utils.h"
@@ -54,6 +59,11 @@ namespace TranscodingSample
         virtual mfxStatus ProcessResult();
 
     protected:
+#if (defined(_WIN32) || defined(_WIN64)) && (MFX_VERSION >= 1031)
+        mfxStatus QueryAdapters();
+        void      ForceImplForSession(mfxU32 idxSession);
+        mfxStatus CheckAndFixAdapterDependency(mfxU32 idxSession, CTranscodingPipeline * pParentPipeline);
+#endif
         virtual mfxStatus VerifyCrossSessionsOptions();
         virtual mfxStatus CreateSafetyBuffers();
         virtual void      DoTranscoding();
@@ -85,6 +95,11 @@ namespace TranscodingSample
     private:
         DISALLOW_COPY_AND_ASSIGN(Launcher);
 
+#if (defined(_WIN32) || defined(_WIN64)) && (MFX_VERSION >= 1031)
+        std::vector<mfxAdapterInfo> m_DisplaysData;
+        mfxAdaptersInfo             m_Adapters;
+#endif
+
     };
 }
 
